@@ -6,24 +6,6 @@
 import time
 
 
-class SensorInfo:
-    pass
-
-
-class Observation:
-
-    def __init__(self):
-
-        # Observation value.
-        self.value = None
-
-        # Observation unit.
-        self.unit = None
-
-        # Observation channel.
-        self.channel = None
-
-
 class SensorReading:
     """
     Object for holding a sensor reading.
@@ -33,9 +15,6 @@ class SensorReading:
         # Reference to the sensor object.
         self.sensor = None
 
-        # List of Observation objects holding sensor values.
-        self.observations = []
-
         # Data dictionary of sensor values.
         self.data = None
 
